aboutsummaryrefslogtreecommitdiffstats
path: root/copy.sh
diff options
context:
space:
mode:
authorJa.KooLit <85185940+JaKooLit@users.noreply.github.com>2025-02-19 00:17:45 +0900
committerGitHub <noreply@github.com>2025-02-19 00:17:45 +0900
commit259be5801f64ddcec5bdc7d97512322079c57314 (patch)
tree00a1a8549388f6286027ca3859963102f80a40c2 /copy.sh
parent7ed5afe7c68777c83b99fffae067374d508eb9b9 (diff)
parent6545cbd6f3cc7620f53e5872e018ea8c0b91d9d8 (diff)
Merge pull request #561 from JaKooLit/main
main to development
Diffstat (limited to 'copy.sh')
-rwxr-xr-xcopy.sh10
1 files changed, 5 insertions, 5 deletions
diff --git a/copy.sh b/copy.sh
index a12dc13a..84a1a215 100755
--- a/copy.sh
+++ b/copy.sh
@@ -36,8 +36,8 @@ print_color() {
printf "%b%s%b\n" "$1" "$2" "$CLEAR"
}
-# Check if dpkg is installed (use to check if Debian or Ubuntu or based distros)
-if command -v dpkg &> /dev/null; then
+# Check /etc/os-release to see if this is an Ubuntu or Debian based distro
+if grep -iq '^\(ID_LIKE\|ID\)=.*\(debian\|ubuntu\)' /etc/os-release >/dev/null 2>&1; then
printf "\n%.0s" {1..1}
print_color $WARNING "
█▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀█
@@ -115,7 +115,7 @@ if hostnamectl | grep -q 'Operating System: NixOS'; then
fi
# Check if dpkg is installed (use to check if Debian or Ubuntu or based distros
-if command -v dpkg &> /dev/null; then
+if grep -iq '^\(ID_LIKE\|ID\)=.*\(debian\|ubuntu\)' /etc/os-release >/dev/null 2>&1; then
echo "${INFO} Debian/Ubuntu based distro. Disabling pyprland since it does not work properly" 2>&1 | tee -a "$LOG" || true
# disabling pyprland as causing issues
sed -i '/^exec-once = pypr &/ s/^/#/' config/hypr/UserConfigs/Startup_Apps.conf
@@ -333,7 +333,7 @@ if [ "$resolution" == "< 1440p" ]; then
# Change rofi font size
find "$themes_dir" -type f | while read -r file; do
if grep -Pzoq 'element-text {\n font: "JetBrainsMono Nerd Font SemiBold 12";\n}' "$file"; then
- sed -i 's/font: "JetBrainsMono Nerd Font SemiBold 12"/font: "JetBrainsMono Nerd Font SemiBold 11"/' "$file"
+ sed -i 's/font: "JetBrainsMono Nerd Font SemiBold 12"/font: "JetBrainsMono Nerd Font SemiBold 10"/' "$file"
fi
done
@@ -851,4 +851,4 @@ printf "\n%.0s" {1..1}
printf "${INFO} However, it is ${MAGENTA}HIGHLY SUGGESTED${RESET} to logout and re-login or better reboot to avoid any issues"
printf "\n%.0s" {1..1}
printf "${SKY_BLUE}Thank you${RESET} for using ${MAGENTA}KooL's Hyprland Configuration${RESET}... ${YELLOW}ENJOY!!!${RESET}"
-printf "\n%.0s" {1..3} \ No newline at end of file
+printf "\n%.0s" {1..3}
send patches to the email below
yukais@pinapelz.com
include the subject [PATCH repo_name]
pinapelz.com
homepage